@@ -11,7 +11,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+"""
+Uses `oslotest`_.
 
+.. _oslotest: https://opendev.org/openstack/oslotest
+"""
 import pbr.version
 
 
